@@ -1,4 +1,4 @@
-pub use fastly_shared::CacheOverride;
+pub use fastly_shared::{CacheOverride, FramingHeadersMode};
 pub use fastly_sys::ContentEncodings;
 
 use super::pending::handle::PendingRequestHandle;
@@ -10,7 +10,6 @@ use bytes::{BufMut, BytesMut};
 use http::header::{HeaderName, HeaderValue};
 use http::{Method, Uri, Version};
 use lazy_static::lazy_static;
-use std::convert::{TryFrom, TryInto};
 use std::mem::ManuallyDrop;
 use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};
 use std::sync::atomic::{AtomicBool, Ordering};
@@ -757,6 +756,13 @@ impl RequestHandle {
         .result()
         .expect("fastly_http_req::auto_decompress_response_set failed")
     }
+
+    /// Sets the way that framing headers are determined for this request.
+    pub fn set_framing_headers_mode(&mut self, mode: FramingHeadersMode) {
+        unsafe { abi::fastly_http_req::framing_headers_mode_set(self.as_u32(), mode) }
+            .result()
+            .expect("fastly_http_req::framing_headers_mode_set failed")
+    }
 }
 
 impl Drop for RequestHandle {
