@@ -5,9 +5,9 @@ use crate::handle::{BodyHandle, StreamingBodyHandle};
 use crate::http::request::SendError;
 use crate::http::request::SendErrorCause;
 use bytes::{BufMut, BytesMut};
+use fastly_shared::FramingHeadersMode;
 use http::header::{HeaderName, HeaderValue};
 use http::{StatusCode, Version};
-use std::convert::TryFrom;
 use std::mem::ManuallyDrop;
 
 // This import is just to get `RequestHandle` into scope for intradoc linking.
@@ -442,6 +442,13 @@ impl ResponseHandle {
             .expect("fastly_http_resp::send_downstream failed")
     }
 
+    /// Sets the way that framing headers are determined for this response.
+    pub fn set_framing_headers_mode(&mut self, mode: FramingHeadersMode) {
+        unsafe { abi::fastly_http_resp::framing_headers_mode_set(self.as_u32(), mode) }
+            .result()
+            .expect("fastly_http_resp::framing_headers_mode_set failed")
+    }
+
     /// Close the ResponseHandle by removing it from the host Session. If the handle has already
     /// been closed an error will be returned. A ResponseHandle is only consumed
     /// when you send a response to a client or stream one to a client. You
